:github_url: https://github.com/pytorch/botorch

BoTorch API Reference
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. toctree::
   :maxdepth: 1
   :caption: API Reference

   acquisition
   models
   generation
   posteriors
   optim
   fit
   sampling
   cross_validation
   settings
   logging
   test_functions
   exceptions
   utils
   distributions


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
